#!/bin/bash
# Script to check if everything is fine with systemtap installation
#

#set -x

LANG=C; export LANG

if [ -e /etc/redhat-release ]; then
	DISTRO="REDHAT"
elif [ -e /etc/SuSE-release ]; then
	DISTRO="SUSE"
elif [ -e /etc/debian_version ]; then
	DISTRO="DEBIAN"
else
	DISTRO="OTHER"
fi

if [[ ! -x /usr/bin/stap ]]  && [[ ! -x /usr/local/bin/stap ]] ; then
	echo "Systemtap not installed in your system."
	if [[ $DISTRO == "REDHAT" ]]; then
		echo "Try running: 'yum install systemtap'"
	elif [[ $DISTRO == "SUSE" ]]; then
		echo "Try running 'zypper install systemtap' or installing systemtap using yast"
	elif [[ $DISTRO == "DEBIAN" ]]; then
		echo "Try running 'apt-get install systemtap'"
	else
		echo "Try installing systemtap"
	fi
	exit 1
fi

if [[ $DISTRO == "SUSE" ]] || [[ $DISTRO == "REDHAT" ]] ; then
	MISSING=$(rpm -q kernel-debuginfo kernel-devel | grep 'not installed' | cut -d ' ' -f 2)
elif [[ $DISTRO == "DEBIAN" ]]; then
	MISSING=$(dpkg -l linux-image-`uname -r`-dbgsym 2>&1 | awk 'BEGIN {pkgs="";} $0 ~ /no packages found/ { pkgs = $6 " " pkgs} END {print pkgs}')
else
	exit 0
fi

if [[ "$MISSING" != "" ]]; then
	echo "The following packages need to be installed:"
	echo $MISSING
	exit 2
fi

exit 0
